# raw2fits
A Python package to convert camera raw images to astronomical fits files.

## Installation
```bash
pip install raw2fits
```

## Usage
```python
import raw2fits
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)

## Acknowledgements
This extraction of the bayer image is based on the [rawpy](https://github.com/letmaik/rawpy).